@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package WWW::xkcd;
 {
-  $WWW::xkcd::VERSION = '0.003';
+  $WWW::xkcd::VERSION = '0.004';
 }
 # ABSTRACT: Synchronous and asynchronous interfaces to xkcd comics
 
@@ -11,6 +11,9 @@ use JSON;
 use Try::Tiny;
 use HTTP::Tiny;
 
+my $can_async = try   { require AnyEvent; require AnyEvent::HTTP; 1 }
+                catch { 0 };
+
 sub new {
     my $class = shift;
     my %args  = (
@@ -32,11 +35,8 @@ sub fetch_metadata {
 
     if ($cb) {
         # this is async
-        eval "use AnyEvent";
-        $@ and croak 'AnyEvent is required for async mode';
-
-        eval 'use AnyEvent::HTTP';
-        $@ and croak 'AnyEvent::HTTP is required for async mode';
+        croak 'AnyEvent and AnyEvent::HTTP are required for async mode'
+            unless $can_async;
 
         AnyEvent::HTTP::http_get( $url, sub {
             my $body = shift;
@@ -83,10 +83,8 @@ sub fetch {
         return 0;
     }
 
-    my $meta = $self->fetch_metadata($comic);
-    my $img  = $meta->{'img'};
-
-    # FIXME: this is copied and should be refactored
+    my $meta   = $self->fetch_metadata($comic);
+    my $img    = $meta->{'img'};
     my $result = HTTP::Tiny->new->get($img);
 
     $result->{'success'} or croak "Can't fetch $img: " .
@@ -137,7 +135,7 @@ WWW::xkcd - Synchronous and asynchronous interfaces to xkcd comics
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
